ByteUtils mixin

Utility methods for converting between integer and big endian bytes.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

intFromBigEndianBytes(List<int> bytes) int
Return an integer representing a Uint8List of big endian bytes.
intToBigEndianBytes(int value, {int length = 8}) Uint8List
Return a Uint8List of big endian bytes representing an integer.